#[repr(i32)]pub enum FetchMode {
Unspecified = 0,
RowsOnly = 1,
WithTies = 2,
}Expand description
Determines how a fetch operation handles rows tied with the last returned row.
Variants
Unspecified = 0
Unspecified. Producers must set one of the defined modes.
RowsOnly = 1
Only return the requested number of rows.
WithTies = 2
Include additional rows tied with the last row (per the sort fields).
Implementations
Sourceimpl FetchMode
impl FetchMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.