VariableEvaluationMode

Enum VariableEvaluationMode 

#[repr(i32)]
pub enum VariableEvaluationMode { Unspecified = 0, PerPlan = 1, PerRecord = 2, }
VariableEvaluationMode specifies the frequency and scope of execution context variable evaluation.

Variants



Unspecified = 0



PerPlan = 1

Variables are evaluated once per Substrait plan execution.



PerRecord = 2

Variables are evaluated once per record during execution.

Implementations

Source

impl VariableEvaluationMode

pub const fn is_valid(value: i32) -> bool

Returns true if value is a variant of VariableEvaluationMode.

pub fn from_i32(value: i32) -> Option<VariableEvaluationMode>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a VariableEvaluationMode, or None if value is not a valid variant.

Source

impl VariableEvaluationMode

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.