pub struct SwitchingField {
pub duplicates: Vec<Expression>,
}Fields
duplicates: Vec<Expression>All duplicates must return the same type class but may differ in nullability. The effective type of the output field will be nullable if any of the duplicate expressions are nullable.