pub struct IntervalDayToSecond {
pub days: i32,
pub seconds: i32,
pub precision: i32,
pub subseconds: i64,
}Fields
days: i32seconds: i32precision: i32Sub-second precision, 0 means the value given is in seconds, 3 is milliseconds, 6 microseconds, 9 is nanoseconds, 12 is picoseconds. Should be used with subseconds below.
subseconds: i64The sub-second component only, expressed as the number of 1e(-precision) units (e.g. with precision 12 this is a number of picoseconds in the range [0, 1e12)). Whole seconds belong in the seconds field above, not here. Should only be used with precision field.