pub struct FieldReference {
pub reference_type: Option<ReferenceType>,
pub root_type: Option<RootType>,
}Expand description
A reference to data within a structured object, supporting navigation into nested fields. The root_type specifies the origin of the data (input record, outer query, lambda parameters, or an arbitrary expression), and the reference_type specifies how to navigate from that root (either a direct path to a single element or a mask selecting multiple elements).
Fields
reference_type: Option<ReferenceType>Whether this is composed of a single element reference or a masked element subtree
root_type: Option<RootType>The origin of the data being referenced. When this is a RootReference and direct_reference above is used, the direct_reference must be of a type StructField.