Literal

Struct Literal 

pub struct Literal {
    pub nullable: bool,
    pub type_variation_reference: u32,
    pub literal_type: Option<LiteralType>,
}

Fields

nullable: bool

Whether the literal_type above should be treated as a nullable type. Applies to all members of the literal_type oneof EXCEPT:

  • Type null (must be nullable by definition)
  • Type.List empty_list (use Type.List::nullability)
  • Type.Map empty_map (use Type.Map::nullability)
type_variation_reference: u32

optionally points to a type_variation_anchor defined in this plan. Applies to all members of union other than the Typed null (which should directly declare the type variation).

literal_type: Option<LiteralType>