pub struct SetPredicate {
pub predicate_op: i32,
pub tuples: Option<Box<Rel>>,
}Expand description
A predicate over a set of rows in the form of a subquery EXISTS and UNIQUE are common SQL forms of this operation.
Fields
predicate_op: i32TODO: should allow expressions
tuples: Option<Box<Rel>>Implementations
Sourceimpl SetPredicate
impl SetPredicate
Sourcepub fn predicate_op(&self) -> PredicateOp
pub fn predicate_op(&self) -> PredicateOp
Returns the enum value of predicate_op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_predicate_op(&mut self, value: PredicateOp)
pub fn set_predicate_op(&mut self, value: PredicateOp)
Sets predicate_op to the provided enum value.