Following

Struct Following 

pub struct Following {
    pub offset: i64,
}
Defines that the bound extends this far ahead of the current record.

Fields

offset: i64

A strictly positive integer specifying the number of records that the window extends ahead of the current record. Required. Use CurrentRow for offset zero and Preceding for negative offsets.