#[repr(i32)]pub enum BoundsType {
Unspecified = 0,
Rows = 1,
Range = 2,
}Variants
Unspecified = 0
Unspecified. Producers must set one of the defined bounds type.
Rows = 1
Bounds are physical row offsets in the declared ordering in sorts.
If no ordering is declared, no order is guaranteed.
Range = 2
Bounds are value offsets from the current row’s ordering value.
This bounds type requires exactly one ordering expression if Preceding or Following is used.
Preceding moves toward values earlier in the declared ordering in sorts;
Following moves toward values later in the declared ordering in sorts.
Bounds are inclusive.
Implementations
Sourceimpl BoundsType
impl BoundsType
Sourceimpl BoundsType
impl BoundsType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.