pub struct AdvancedExtension {
pub optimization: Vec<Any>,
pub enhancement: Option<Any>,
}Expand description
A generic object that can be used to embed additional extension information into the serialized substrait plan.
Fields
optimization: Vec<Any>An optimization is helpful information that don’t influence semantics. May be ignored by a consumer.
enhancement: Option<Any>An enhancement alter semantics. Cannot be ignored by a consumer.