pub struct ComparisonJoinKey {
pub left: Option<FieldReference>,
pub right: Option<FieldReference>,
pub comparison: Option<ComparisonType>,
}Expand description
Hash joins and merge joins are a specialization of the general join where the join expression is an series of comparisons between fields that are ANDed together. The behavior of this comparison is flexible
Fields
left: Option<FieldReference>The key to compare from the left table
right: Option<FieldReference>The key to compare from the right table
comparison: Option<ComparisonType>Describes how to compare the two keys