DdlRel

Struct DdlRel 

pub struct DdlRel {
    pub table_schema: Option<NamedStruct>,
    pub table_defaults: Option<Struct>,
    pub object: i32,
    pub op: i32,
    pub view_definition: Option<Box<Rel>>,
    pub common: Option<RelCommon>,
    pub advanced_extension: Option<AdvancedExtension>,
    pub write_type: Option<WriteType>,
}

Fields

table_schema: Option<NamedStruct>

The columns that will be modified (representing after-image of a schema change)

table_defaults: Option<Struct>

The default values for the columns (representing after-image of a schema change) E.g., in case of an ALTER TABLE that changes some of the column default values, we expect the table_defaults Struct to report a full list of default values reflecting the result of applying the ALTER TABLE operator successfully

object: i32

Which type of object we operate on

op: i32

The type of operation to perform

view_definition: Option<Box<Rel>>

The body of the CREATE VIEW

common: Option<RelCommon>advanced_extension: Option<AdvancedExtension>write_type: Option<WriteType>

Definition of which type of object we are operating on

Implementations

Source

impl DdlRel

pub fn object(&self) -> DdlObject

Returns the enum value of object, or the default if the field is set to an invalid enum value.

pub fn set_object(&mut self, value: DdlObject)

Sets object to the provided enum value.

pub fn op(&self) -> DdlOp

Returns the enum value of op, or the default if the field is set to an invalid enum value.

pub fn set_op(&mut self, value: DdlOp)

Sets op to the provided enum value.