DynamicParameter

Struct DynamicParameter 

pub struct DynamicParameter {
    pub type: Option<Type>,
    pub parameter_reference: u32,
}
Expression that represents a dynamic parameter. Dynamic parameters are identified by a surrogate key within a plan.

Fields

type: Option<Type>

The type of the dynamic parameter.

parameter_reference: u32

The surrogate key used within a plan to reference a specific parameter binding. 0 is a valid anchor/reference, but prefer non-zero values for ergonomics.