pub struct DynamicParameterBinding {
pub parameter_anchor: u32,
pub value: Option<Literal>,
}Expand description
Represents a binding for a dynamic parameter.
Fields
parameter_anchor: u32The parameter anchor that identifies the dynamic parameter reference. 0 is a valid anchor/reference, but prefer non-zero values for ergonomics.
value: Option<Literal>The literal value assigned to the parameter at runtime. The type of the literal needs to match the type of the corresponding DynamicParameter expression in the plan.