pub struct ExecutionBehavior {
pub variable_eval_mode: i32,
}Expand description
ExecutionBehavior specifies the execution behavior for plan evaluation.
Fields
variable_eval_mode: i32Defines the scope of execution context variable evaluation during plan execution.
Implementations
Sourceimpl ExecutionBehavior
impl ExecutionBehavior
Sourcepub fn variable_eval_mode(&self) -> VariableEvaluationMode
pub fn variable_eval_mode(&self) -> VariableEvaluationMode
Returns the enum value of variable_eval_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_variable_eval_mode(&mut self, value: VariableEvaluationMode)
pub fn set_variable_eval_mode(&mut self, value: VariableEvaluationMode)
Sets variable_eval_mode to the provided enum value.