pub struct ExpandRel {
pub common: Option<RelCommon>,
pub input: Option<Box<Rel>>,
pub fields: Vec<ExpandField>,
}Expand description
Duplicates records by emitting one or more rows per input row. The number of rows emitted per input row is the same for all input rows.
In addition to a field being emitted per input field an extra int64 field is emitted which contains a zero-indexed ordinal corresponding to the duplicate definition.
Fields
common: Option<RelCommon>input: Option<Box<Rel>>fields: Vec<ExpandField>There should be one definition here for each input field. Any fields beyond the provided definitions will be emitted as is (as if a consistent_field record with an identity expression was provided).