pub struct JoinRel {
pub common: Option<RelCommon>,
pub left: Option<Box<Rel>>,
pub right: Option<Box<Rel>>,
pub expression: Option<Box<Expression>>,
pub post_join_filter: Option<Box<Expression>>,
pub type: i32,
pub advanced_extension: Option<AdvancedExtension>,
}Expand description
The binary JOIN relational operator left-join-right, including various join types, a join condition, and an optional filter on the joined output.
Fields
common: Option<RelCommon>left: Option<Box<Rel>>right: Option<Box<Rel>>expression: Option<Box<Expression>>A boolean condition evaluated over the left and right inputs that determines whether a pair of records is a match.
post_join_filter: Option<Box<Expression>>An optional boolean filter applied to each output record after join-type-specific output formation is complete. Semantically equivalent to placing a FilterRel directly above this join.
type: i32advanced_extension: Option<AdvancedExtension>Implementations