pub struct LateralJoinRel {
pub common: Option<RelCommon>,
pub left: Option<Box<Rel>>,
pub right: Option<Box<Rel>>,
pub expression: Option<Box<Expression>>,
pub post_join_filter: Option<Box<Expression>>,
pub type: i32,
pub advanced_extension: Option<AdvancedExtension>,
}Expand description
The binary lateral JOIN relational operator left-join-right. This is semantically identical to JoinRel, except the right input is evaluated once per row of the left input and may reference fields from the current left row via OuterReference rel_reference.
LateralJoinRel must set RelCommon.rel_anchor so the right input can reference fields of the current left row.
Fields
common: Option<RelCommon>left: Option<Box<Rel>>The independent input whose rows drive evaluation of the lateral join.
right: Option<Box<Rel>>The dependent input evaluated once per left row. It may reference fields from the current left row using OuterReference.rel_reference pointing to this LateralJoinRel’s RelCommon.rel_anchor.
expression: Option<Box<Expression>>A boolean condition evaluated over the left and right inputs that determines whether a pair of records is a match.
post_join_filter: Option<Box<Expression>>An optional boolean filter applied to each output record after join-type-specific output formation is complete. Semantically equivalent to placing a FilterRel directly above this join.
type: i32Only INNER and left-oriented join types are valid for lateral joins: INNER, LEFT, LEFT_SEMI, LEFT_ANTI, LEFT_SINGLE, LEFT_MARK. RIGHT-oriented join types and OUTER are not valid because the right input is evaluated in the context of each left row and has no independent existence.
advanced_extension: Option<AdvancedExtension>Implementations