MergeJoinRel

Struct MergeJoinRel 

pub struct MergeJoinRel {
    pub common: Option<RelCommon>,
    pub left: Option<Box<Rel>>,
    pub right: Option<Box<Rel>>,
    pub keys: Vec<ComparisonJoinKey>,
    pub post_join_filter: Option<Box<Expression>>,
    pub type: i32,
    pub residual_expression: Option<Box<Expression>>,
    pub advanced_extension: Option<AdvancedExtension>,
}
The merge join does a join by taking advantage of two sets that are sorted on the join keys. This allows the join operation to be done in a streaming fashion.

Fields

common: Option<RelCommon>left: Option<Box<Rel>>right: Option<Box<Rel>>keys: Vec<ComparisonJoinKey>

One or more keys to join on. The relation is invalid if this is empty.

If a custom comparison function is used then it must be consistent with the ordering of the input data. For example, if the comparison function is “<” then we generally expect the data to be sorted in ascending order.

If the comparison function is something like “less than ignoring case” then the data should be sorted appropriately (e.g. both “A” and “a” should come before “b”)

The sort order is not specified here. It is typically the responsibility of the producer to ensure the plan sorts the data if needed (although the consumer is free to do so as well). If possible, the consumer should verify the sort order and reject invalid plans.

post_join_filter: Option<Box<Expression>>

An optional boolean filter applied to each output record after join-type-specific output formation is complete. Semantically equivalent to placing a FilterRel directly above this join.

type: i32residual_expression: Option<Box<Expression>>

An optional boolean expression evaluated on each candidate key-match to determine whether it is a true match. A candidate is only considered a match when all keys comparisons AND this expression evaluate to true. This expression interacts with join-type semantics: for example, in a left outer join, a left row that has key matches but no candidate satisfying this expression will be emitted with nulls for the right side.

advanced_extension: Option<AdvancedExtension>

Implementations

Source

impl MergeJoinRel

pub fn type(&self) -> JoinType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: JoinType)

Sets type to the provided enum value.