NamedStruct

Struct NamedStruct 

pub struct NamedStruct {
    pub names: Vec<String>,
    pub struct: Option<Struct>,
}
A message for modeling name/type pairs.

Useful for representing relation schemas.

Notes:

  • The names field is in depth-first order.

For example a schema such as:

a: int64 b: struct<c: float32, d: string>

would have a names field that looks like:

[“a”, “b”, “c”, “d”]

  • Only struct fields are contained in this field’s elements,
  • Map keys should be traversed first, then values when producing/consuming
  • When used to represent a relation schema, the outermost struct’s nullability should be NULLABILITY_REQUIRED.

Fields

names: Vec<String>

list of names in dfs order

struct: Option<Struct>