RelCommon

Struct RelCommon 

pub struct RelCommon {
    pub hint: Option<Hint>,
    pub advanced_extension: Option<AdvancedExtension>,
    pub rel_anchor: Option<u32>,
    pub emit_kind: Option<EmitKind>,
}
Common fields for all relational operators

Fields

hint: Option<Hint>advanced_extension: Option<AdvancedExtension>rel_anchor: Option<u32>

Optional plan-wide unique identifier for this relation. Required when this relation is the binding point for an OuterReference using rel_reference. Must be unique across all rels within a Plan. Must be >= 1 when set.

emit_kind: Option<EmitKind>

Implementations

Source

impl RelCommon

pub fn rel_anchor(&self) -> u32

Returns the value of rel_anchor, or the default value if rel_anchor is unset.