pub struct TopNRel {
pub common: Option<RelCommon>,
pub input: Option<Box<Rel>>,
pub sorts: Vec<SortField>,
pub offset: Option<Box<Expression>>,
pub count: Option<Box<Expression>>,
pub mode: i32,
pub advanced_extension: Option<AdvancedExtension>,
}Expand description
The top-N relational operator. A combination of a sort and fetch that only maintains the number of records required to ensure a limited output.
Fields
common: Option<RelCommon>input: Option<Box<Rel>>sorts: Vec<SortField>List of one or more fields to sort by. At least one is required.
offset: Option<Box<Expression>>Expression evaluating to a non-negative integer specifying the number of records to skip. Null is treated as 0. Recommended type is int64.
count: Option<Box<Expression>>Expression evaluating to a non-negative integer specifying the number of records to return. Null signals ALL. Recommended type is int64.
mode: i32Determines how to handle rows tied with the last returned row.
advanced_extension: Option<AdvancedExtension>Implementations