UpdateRel

Struct UpdateRel 

pub struct UpdateRel {
    pub table_schema: Option<NamedStruct>,
    pub condition: Option<Box<Expression>>,
    pub transformations: Vec<TransformExpression>,
    pub advanced_extension: Option<AdvancedExtension>,
    pub update_type: Option<UpdateType>,
}
The operator that modifies the columns of a table

Fields

table_schema: Option<NamedStruct>

The full schema of the named_table

condition: Option<Box<Expression>>

condition to be met for the update to be applied on a record

transformations: Vec<TransformExpression>

The list of transformations to apply to the columns of the named_table

advanced_extension: Option<AdvancedExtension>update_type: Option<UpdateType>