pub struct Version {
pub major_number: u32,
pub minor_number: u32,
pub patch_number: u32,
pub git_hash: String,
pub producer: String,
}Fields
major_number: u32Substrait version number.
minor_number: u32patch_number: u32git_hash: StringIf a particular version of Substrait is used that does not correspond to a version number exactly (for example when using an unofficial fork or using a version that is not yet released or is between versions), set this to the full git hash of the utilized commit of https://github.com/substrait-io/substrait (or fork thereof), represented using a lowercase hex ASCII string 40 characters in length. The version number above should be set to the most recent version tag in the history of that commit.
producer: StringIdentifying information for the producer that created this plan. Under ideal circumstances, consumers should not need this information. However, it is foreseen that consumers may need to work around bugs in particular producers in practice, and therefore may need to know which producer created the plan.