pub enum Kind {
Show 28 variants
Bool(Boolean),
I8(I8),
I16(I16),
I32(I32),
I64(I64),
Fp32(Fp32),
Fp64(Fp64),
String(String),
Binary(Binary),
Date(Date),
IntervalYear(IntervalYear),
IntervalDay(IntervalDay),
IntervalCompound(IntervalCompound),
Uuid(Uuid),
FixedChar(FixedChar),
Varchar(VarChar),
FixedBinary(FixedBinary),
Decimal(Decimal),
PrecisionTime(PrecisionTime),
PrecisionTimestamp(PrecisionTimestamp),
PrecisionTimestampTz(PrecisionTimestampTz),
Struct(Struct),
List(Box<List>),
Map(Box<Map>),
Func(Box<Func>),
Unbound(Unbound),
UserDefined(UserDefined),
Alias(TypeAliasReference),
}Variants
Bool(Boolean)
I8(I8)
I16(I16)
I32(I32)
I64(I64)
Fp32(Fp32)
Fp64(Fp64)
String(String)
Binary(Binary)
Date(Date)
IntervalYear(IntervalYear)
IntervalDay(IntervalDay)
IntervalCompound(IntervalCompound)
Uuid(Uuid)
FixedChar(FixedChar)
Varchar(VarChar)
FixedBinary(FixedBinary)
Decimal(Decimal)
PrecisionTime(PrecisionTime)
PrecisionTimestamp(PrecisionTimestamp)
PrecisionTimestampTz(PrecisionTimestampTz)
value is since UNIX epoch in UTC
Struct(Struct)
List(Box<List>)
Map(Box<Map>)
Func(Box<Func>)
Unbound(Unbound)
A placeholder type whose concrete type has not yet been bound. Unbound may be used where a concrete type would normally appear in partially bound plans and expressions, and must be bound to a concrete type before execution. Substrait defines no runtime semantics for values whose type is unbound.
UserDefined(UserDefined)
Alias(TypeAliasReference)
Reference an aliased type in Plan.type_aliases.
Implementations
Sourceimpl Kind
impl Kind
Sourcepub fn merge(
field: &mut Option<Kind>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Kind>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.