I64

Struct I64 

pub struct I64 {
    pub type_variation_reference: u32,
    pub nullability: i32,
}

Fields

type_variation_reference: u32nullability: i32

Implementations

Source

impl I64

pub fn nullability(&self) -> Nullability

Returns the enum value of nullability, or the default if the field is set to an invalid enum value.

pub fn set_nullability(&mut self, value: Nullability)

Sets nullability to the provided enum value.