pub struct IntervalCompound {
pub type_variation_reference: u32,
pub nullability: i32,
pub precision: i32,
}Expand description
An interval consisting of the components of both IntervalYear and IntervalDay
Fields
type_variation_reference: u32nullability: i32precision: i32Sub-second precision, 0 means the value given is in seconds, 3 is milliseconds, 6 microseconds, 9 is nanoseconds, 12 is picoseconds
Implementations
Sourceimpl IntervalCompound
impl IntervalCompound
Sourcepub fn nullability(&self) -> Nullability
pub fn nullability(&self) -> Nullability
Returns the enum value of nullability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_nullability(&mut self, value: Nullability)
pub fn set_nullability(&mut self, value: Nullability)
Sets nullability to the provided enum value.