Map

Struct Map 

pub struct Map {
    pub key: Option<Box<Type>>,
    pub value: Option<Box<Type>>,
    pub type_variation_reference: u32,
    pub nullability: i32,
}

Fields

key: Option<Box<Type>>value: Option<Box<Type>>type_variation_reference: u32nullability: i32

Implementations

Source

impl Map

pub fn nullability(&self) -> Nullability

Returns the enum value of nullability, or the default if the field is set to an invalid enum value.

pub fn set_nullability(&mut self, value: Nullability)

Sets nullability to the provided enum value.