pub struct TimestampTz {
pub type_variation_reference: u32,
pub nullability: i32,
}Fields
type_variation_reference: u32nullability: i32Implementations
Sourceimpl TimestampTz
impl TimestampTz
Sourcepub fn nullability(&self) -> Nullability
pub fn nullability(&self) -> Nullability
Returns the enum value of nullability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_nullability(&mut self, value: Nullability)
pub fn set_nullability(&mut self, value: Nullability)
Sets nullability to the provided enum value.