pub struct Lambda {
pub parameters: Option<Struct>,
pub body: Option<Box<Expression>>,
}Expand description
A lambda expression representing an inline, anonymous function. Lambda expressions have parameters and a body expression that can reference those parameters using FieldReference with FieldReference.LambdaParameterReference as the root_type.
Fields
parameters: Option<Struct>Parameters this lambda accepts, represented as a struct where each field corresponds to a parameter. Parameters can be accessed using FieldReference with FieldReference.LambdaParameterReference as root_type and StructField to select specific parameters. The struct’s nullability must be NULLABILITY_REQUIRED.
body: Option<Box<Expression>>The lambda body expression. Lambda parameters can be referenced using FieldReference with FieldReference.LambdaParameterReference as root_type.