Module bound

Module bound 

Nested message and enum types in Bound.

Structs

CurrentRow
Defines that the bound extends to or from the current record under BOUNDS_TYPE_ROWS, or to or from the current peer group under BOUNDS_TYPE_RANGE. A peer group is the set of records with equal sort key values, where two null sort key values are considered equal.
Following
Defines a bound later than the current record in the declared ordering in sorts.
Preceding
Defines a bound earlier than the current record in the declared ordering in sorts.
Unbounded
Defines an “unbounded bound”: for lower bounds this means the start of the partition, and for upper bounds this means the end of the partition.

Enums

Kind